@@ -26,6 +26,7 @@ class Diff2HTMLTransform(Transform):
     def __init__(self, ipcb):
         # insert point callback
         self._ipcb = ipcb
+        self._counter = 0
 
     def _convert(self, trdata):
         cw = trdata.appobject._cw
@@ -63,8 +64,12 @@ class Diff2HTMLTransform(Transform):
                     '+': 'diffNewLine',
                     ' ': 'diffLine',
                     '\\': 'diffOldLine'}[line[0]]
+        self._counter += 1
+        w(u'<span class="lineCount">%s</span> ' % self._counter)
         if line.strip():
             w(u'<span class="%s">%s</span>\n' % (cssclass, xml_escape(line)))
+        else:
+            w('\n')
 
     def comment_line(self, trdata, w, line):
         w(xml_escape(line) + '<br/>')
