@@ -29,7 +29,8 @@ def fire(patch, trname, comment):
 
 
 class LinkOrCreatePatchOp(hook.DataOperationMixIn, hook.Operation):
-    containercls = list
+    """operation to track patch's state according to incoming revisions"""
+    containercls = list # operation order matters
 
     def precommit_event(self):
         for entity in self.get_data():
@@ -57,7 +58,9 @@ class LinkOrCreatePatchOp(hook.DataOperationMixIn, hook.Operation):
             patch.set_relations(patch_revision=entity)
             # patch file is being removed: mark it on the patch entity if still
             # active
-            if entity.__regid__ == 'DeletedVersionContent' and patch.is_active():
+            if (entity.__regid__ == 'DeletedVersionContent'
+                and patch.is_active()
+                and entity.rev.branch == patch.branch):
                 MarkPatchAsDeletedOp.get_instance(self.session).add_data(patch)
 
 
