@@ -15,6 +15,9 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 """cubicweb-vcreview schema"""
 
+__docformat__ = "restructuredtext en"
+_ = unicode
+
 from yams.buildobjs import EntityType, RelationDefinition, String
 
 from cubicweb.schema import WorkflowableEntityType, RQLConstraint
@@ -40,6 +43,13 @@ class Patch(WorkflowableEntityType):
         'update': ('managers', 'users'),
         'delete': ('managers',),
         }
+    branch = String(
+        maxsize=100, indexed=True,
+        description=_('branch where this patch has been introduced'))
+    originator = String(
+        maxsize=256, indexed=True,
+        description=_('author of the revision which has introduced this patch'))
+
 
 class patch_repository(RelationDefinition):
     # shortcut for P patch_revision VC, VC revision REV, REV from_repository R
@@ -109,10 +119,14 @@ class comments(RelationDefinition):
 
 # notification #################################################################
 
+# XXX Comment should be in list, but this will conflict with the forge cube when
+# using vcreview
 class nosy_list(RelationDefinition):
-    subject = ('Repository', 'Patch', 'Task')
+    subject = ('Repository', 'Patch', 'Task',
+               'VersionContent', 'DeletedVersionContent',
+               'InsertionPoint')
     object = 'CWUser'
 
 class interested_in(RelationDefinition):
     subject = 'CWUser'
-    object = 'Repository'
+    object = ('Repository', 'Patch')
