@@ -25,7 +25,7 @@ class PatchRepositoryFacet(facet.RelationFacet):
     __regid__ = 'vcreview.patch_repository'
     rtype = 'patch_repository'
     role = 'subject'
-    label_vid = 'oneline'
+    label_vid = 'text'
 
 
 class PatchOriginatorFacet(facet.AttributeFacet):
