@@ -31,11 +31,10 @@ class AllActivePatches(StartupView):
     @cached
     def filter_box_context_info(self):
         rset = self._cw.execute(
-            'Any P,PO,PB,PS,COUNT(TR),COUNT(VC),R GROUPBY R,P,PO,PB,PS '
+            'Any P,PO,PB,PS,COUNT(TR),R GROUPBY R,P,PO,PB,PS '
             'ORDERBY RT,PB,PO WHERE P originator PO, P branch PB, P in_state PS,'
-            'TR wf_info_for P, P patch_revision VC, P patch_repository R, '
-            'PS name IN ("in-progress", "pending-review", "deleted"), '
-            'R title RT'
+            'TR? wf_info_for P, P patch_repository R, R title RT, '
+            'PS name IN ("in-progress", "pending-review", "deleted")'
             )
         return rset, 'vcreview.patches.table', domid(self.__regid__), False
 
